@@ -1,7 +1,7 @@
 ####################################################################
 #
 #     This file was generated using XDR::Parse version v0.3.1,
-#        XDR::Gen version 0.0.2 and LibVirt version v10.3.0
+#        XDR::Gen version 0.0.3 and LibVirt version v10.3.0
 #
 #      Don't edit this file, use the source template instead
 #
@@ -9,7 +9,7 @@
 #
 ####################################################################
 
-package Protocol::Sys::Virt::Transport::XDR v10.3.4;
+package Protocol::Sys::Virt::Transport::XDR v10.3.5;
 
 use v5.14;
 use warnings FATAL => 'uninitialized';
@@ -140,6 +140,8 @@ sub serialize_Header {
         unless defined $_[1];
 
     # Serializing field: 'prog'
+    croak "Missing required input value 'prog'
+        unless exists $_[1]->{prog}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'unsigned int' value"
         unless defined $_[1]->{prog};
@@ -151,6 +153,8 @@ sub serialize_Header {
     $_[2] += 4;
 
     # Serializing field: 'vers'
+    croak "Missing required input value 'vers'
+        unless exists $_[1]->{vers}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'unsigned int' value"
         unless defined $_[1]->{vers};
@@ -162,6 +166,8 @@ sub serialize_Header {
     $_[2] += 4;
 
     # Serializing field: 'proc'
+    croak "Missing required input value 'proc'
+        unless exists $_[1]->{proc}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{proc};
@@ -173,12 +179,14 @@ sub serialize_Header {
     $_[2] += 4;
 
     # Serializing field: 'type'
+    croak "Missing required input value 'type'
+        unless exists $_[1]->{type}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'Type' value"
-        unless defined $_[1]->{type};
     $_[0]->serialize_Type( $_[1]->{type}, $_[2], $_[3] );
 
     # Serializing field: 'serial'
+    croak "Missing required input value 'serial'
+        unless exists $_[1]->{serial}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'unsigned int' value"
         unless defined $_[1]->{serial};
@@ -190,9 +198,9 @@ sub serialize_Header {
     $_[2] += 4;
 
     # Serializing field: 'status'
+    croak "Missing required input value 'status'
+        unless exists $_[1]->{status}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'Status' value"
-        unless defined $_[1]->{status};
     $_[0]->serialize_Status( $_[1]->{status}, $_[2], $_[3] );
 }
 # @_: ($class, $value, $index, $input) = @_;
@@ -286,8 +294,6 @@ sub serialize_String {
         substr( $_[3], $_[2] ) = pack("L>", 1);
         $_[2] += 4;
         # my ($class, $value, $index, $output) = @_;
-        croak "Missing required input 'NonnullString' value"
-            unless defined $_[1];
         $_[0]->serialize_NonnullString( $_[1], $_[2], $_[3] );
     }
     else {
@@ -324,18 +330,20 @@ sub serialize_NonnullDomain {
         unless defined $_[1];
 
     # Serializing field: 'name'
+    croak "Missing required input value 'name'
+        unless exists $_[1]->{name}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'NonnullString' value"
-        unless defined $_[1]->{name};
     $_[0]->serialize_NonnullString( $_[1]->{name}, $_[2], $_[3] );
 
     # Serializing field: 'uuid'
+    croak "Missing required input value 'uuid'
+        unless exists $_[1]->{uuid}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'UUID' value"
-        unless defined $_[1]->{uuid};
     $_[0]->serialize_UUID( $_[1]->{uuid}, $_[2], $_[3] );
 
     # Serializing field: 'id'
+    croak "Missing required input value 'id'
+        unless exists $_[1]->{id}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{id};
@@ -364,15 +372,15 @@ sub serialize_NonnullNetwork {
         unless defined $_[1];
 
     # Serializing field: 'name'
+    croak "Missing required input value 'name'
+        unless exists $_[1]->{name}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'NonnullString' value"
-        unless defined $_[1]->{name};
     $_[0]->serialize_NonnullString( $_[1]->{name}, $_[2], $_[3] );
 
     # Serializing field: 'uuid'
+    croak "Missing required input value 'uuid'
+        unless exists $_[1]->{uuid}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'UUID' value"
-        unless defined $_[1]->{uuid};
     $_[0]->serialize_UUID( $_[1]->{uuid}, $_[2], $_[3] );
 }
 # @_: ($class, $value, $index, $input) = @_;
@@ -406,8 +414,6 @@ sub serialize_Domain {
         substr( $_[3], $_[2] ) = pack("L>", 1);
         $_[2] += 4;
         # my ($class, $value, $index, $output) = @_;
-        croak "Missing required input 'NonnullDomain' value"
-            unless defined $_[1];
         $_[0]->serialize_NonnullDomain( $_[1], $_[2], $_[3] );
     }
     else {
@@ -448,8 +454,6 @@ sub serialize_Network {
         substr( $_[3], $_[2] ) = pack("L>", 1);
         $_[2] += 4;
         # my ($class, $value, $index, $output) = @_;
-        croak "Missing required input 'NonnullNetwork' value"
-            unless defined $_[1];
         $_[0]->serialize_NonnullNetwork( $_[1], $_[2], $_[3] );
     }
     else {
@@ -538,6 +542,8 @@ sub serialize_Error {
         unless defined $_[1];
 
     # Serializing field: 'code'
+    croak "Missing required input value 'code'
+        unless exists $_[1]->{code}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{code};
@@ -549,6 +555,8 @@ sub serialize_Error {
     $_[2] += 4;
 
     # Serializing field: 'domain'
+    croak "Missing required input value 'domain'
+        unless exists $_[1]->{domain}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{domain};
@@ -560,12 +568,14 @@ sub serialize_Error {
     $_[2] += 4;
 
     # Serializing field: 'message'
+    croak "Missing required input value 'message'
+        unless exists $_[1]->{message}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'String' value"
-        unless defined $_[1]->{message};
     $_[0]->serialize_String( $_[1]->{message}, $_[2], $_[3] );
 
     # Serializing field: 'level'
+    croak "Missing required input value 'level'
+        unless exists $_[1]->{level}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{level};
@@ -577,30 +587,32 @@ sub serialize_Error {
     $_[2] += 4;
 
     # Serializing field: 'dom'
+    croak "Missing required input value 'dom'
+        unless exists $_[1]->{dom}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'Domain' value"
-        unless defined $_[1]->{dom};
     $_[0]->serialize_Domain( $_[1]->{dom}, $_[2], $_[3] );
 
     # Serializing field: 'str1'
+    croak "Missing required input value 'str1'
+        unless exists $_[1]->{str1}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'String' value"
-        unless defined $_[1]->{str1};
     $_[0]->serialize_String( $_[1]->{str1}, $_[2], $_[3] );
 
     # Serializing field: 'str2'
+    croak "Missing required input value 'str2'
+        unless exists $_[1]->{str2}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'String' value"
-        unless defined $_[1]->{str2};
     $_[0]->serialize_String( $_[1]->{str2}, $_[2], $_[3] );
 
     # Serializing field: 'str3'
+    croak "Missing required input value 'str3'
+        unless exists $_[1]->{str3}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'String' value"
-        unless defined $_[1]->{str3};
     $_[0]->serialize_String( $_[1]->{str3}, $_[2], $_[3] );
 
     # Serializing field: 'int1'
+    croak "Missing required input value 'int1'
+        unless exists $_[1]->{int1}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{int1};
@@ -612,6 +624,8 @@ sub serialize_Error {
     $_[2] += 4;
 
     # Serializing field: 'int2'
+    croak "Missing required input value 'int2'
+        unless exists $_[1]->{int2}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'int' value"
         unless defined $_[1]->{int2};
@@ -623,9 +637,9 @@ sub serialize_Error {
     $_[2] += 4;
 
     # Serializing field: 'net'
+    croak "Missing required input value 'net'
+        unless exists $_[1]->{net}
     # my ($class, $value, $index, $output) = @_;
-    croak "Missing required input 'Network' value"
-        unless defined $_[1]->{net};
     $_[0]->serialize_Network( $_[1]->{net}, $_[2], $_[3] );
 }
 # @_: ($class, $value, $index, $input) = @_;
@@ -657,6 +671,8 @@ sub serialize_StreamHole {
         unless defined $_[1];
 
     # Serializing field: 'length'
+    croak "Missing required input value 'length'
+        unless exists $_[1]->{length}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'long' value"
         unless defined $_[1]->{length};
@@ -669,6 +685,8 @@ sub serialize_StreamHole {
     $_[2] += 8;
 
     # Serializing field: 'flags'
+    croak "Missing required input value 'flags'
+        unless exists $_[1]->{flags}
     # my ($class, $value, $index, $output) = @_;
     croak "Missing required input 'unsigned int' value"
         unless defined $_[1]->{flags};
@@ -691,7 +709,7 @@ Protocol::Sys::Virt::Transport::XDR - Protocol header and error constants and (d
 
 =head1 VERSION
 
-v10.3.4
+v10.3.5
 
 Based on LibVirt tag v10.3.0
 
